==> netdude_0.3.3.orig.tar.gz: netdude-0.3.3/protocols/fddi/nd_fddi.h <==
/*

Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

#ifndef __nd_fddi_h
#define __nd_fddi_h

#include <netinet/if_fddi.h>

#include <netdude/nd_gettext.h>
#include <netdude/nd_packet.h>
#include <netdude/nd_trace.h>
#include <netdude/nd_protocol.h>

/* These are the implementations of ND_Protocol's callbacks: */
GtkWidget *nd_fddi_create_gui(ND_Trace *trace, ND_ProtoInfo *pinf);
void       nd_fddi_set_gui(const ND_Packet *packet, ND_ProtoInfo *pinf);
void       nd_fddi_init_packet(ND_Packet *packet, guchar *data, guchar *data_end);
gboolean   nd_fddi_header_complete(const ND_Packet *packet, guint nesting);

/* Generic accessor function for the protocol implementation: */
ND_Protocol *nd_fddi_get(void);

/* Helper functions to set a trace's GUI table to a packet's content: */
void       nd_fddi_set_gui_fc(ND_ProtoInfo *pinf, struct fddi_header *fh);
void       nd_fddi_set_gui_dhost(ND_ProtoInfo *pinf, struct fddi_header *fh);
void       nd_fddi_set_gui_shost(ND_ProtoInfo *pinf, struct fddi_header *fh);

#endif

==> netdude-0.4.6.tar.gz: netdude-0.4.6/protocols/fddi/nd_fddi.h <==
/*

Copyright (C) 2000 - 2003 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

#ifndef __nd_fddi_h
#define __nd_fddi_h

#include <nd.h>
#include <protocols/fddi/libnd_fddi.h>

/* These are the implementations of ND_Protocol's callbacks: */
GtkWidget *nd_fddi_create_gui(LND_Trace *trace, LND_ProtoInfo *pinf);
void       nd_fddi_set_gui(const LND_Packet *packet, LND_ProtoInfo *pinf);
void       nd_fddi_init_packet(LND_Packet *packet, guchar *data, guchar *data_end);
gboolean   nd_fddi_header_complete(const LND_Packet *packet, guint nesting);

/* Generic accessor function for the protocol implementation: */
LND_Protocol *nd_fddi_get(void);
ND_Protocol  *nd_fddi_get_gui(void);

/* Helper functions to set a trace's GUI table to a packet's content: */
void       nd_fddi_set_gui_fc(LND_ProtoInfo *pinf, struct fddi_header *fh);
void       nd_fddi_set_gui_dhost(LND_ProtoInfo *pinf, struct fddi_header *fh);
void       nd_fddi_set_gui_shost(LND_ProtoInfo *pinf, struct fddi_header *fh);

#endif
